// /app/maui/clip/views/player/Player.qml
#include <QtQml/qqmlprivate.h>
#include <QtCore/qdatetime.h>
#include <QtCore/qobject.h>
#include <QtCore/qstring.h>
#include <QtCore/qstringlist.h>
#include <QtCore/qtimezone.h>
#include <QtCore/qurl.h>
#include <QtCore/qvariant.h>
#include <QtQml/qjsengine.h>
#include <QtQml/qjsprimitivevalue.h>
#include <QtQml/qjsvalue.h>
#include <QtQml/qqmlcomponent.h>
#include <QtQml/qqmlcontext.h>
#include <QtQml/qqmlengine.h>
#include <QtQml/qqmllist.h>
#include <type_traits>
namespace QmlCacheGeneratedCode {
namespace _app_maui_clip_views_player_Player_qml {
extern const unsigned char qmlData alignas(16) [];
extern const unsigned char qmlData alignas(16) [] = {

0x71,0x76,0x34,0x63,0x64,0x61,0x74,0x61,
0x42,0x0,0x0,0x0,0x2,0x9,0x6,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x74,0x8,0x0,0x0,0x63,0x31,0x31,0x35,
0x66,0x64,0x63,0x38,0x66,0x64,0x31,0x65,
0x36,0x33,0x34,0x62,0x61,0x36,0x30,0x64,
0x31,0x64,0x35,0x61,0x65,0x37,0x38,0x63,
0x63,0x37,0x63,0x33,0x30,0x34,0x32,0x34,
0x39,0x35,0x30,0x32,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x6a,0x68,0xa4,0xa2,
0x28,0x5f,0xaf,0xd,0xc2,0x80,0x1d,0x3,
0x66,0xdc,0x14,0xac,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x23,0x0,0x0,0x0,
0x1c,0x0,0x0,0x0,0x0,0x3,0x0,0x0,
0x5,0x0,0x0,0x0,0xf8,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xc,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0xc,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0xc,0x1,0x0,0x0,
0x10,0x0,0x0,0x0,0xc,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x4c,0x1,0x0,0x0,
0x1,0x0,0x0,0x0,0x50,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x58,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x58,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x58,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x58,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x58,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x58,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x58,0x1,0x0,0x0,
0xff,0xff,0xff,0xff,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xf0,0x6,0x0,0x0,
0x58,0x1,0x0,0x0,0xb0,0x1,0x0,0x0,
0x8,0x2,0x0,0x0,0x60,0x2,0x0,0x0,
0xb0,0x2,0x0,0x0,0x43,0x0,0x0,0x0,
0x40,0x1,0x0,0x0,0x53,0x1,0x0,0x0,
0x60,0x1,0x0,0x0,0x43,0x0,0x0,0x0,
0x40,0x1,0x0,0x0,0x53,0x1,0x0,0x0,
0x70,0x1,0x0,0x0,0x43,0x0,0x0,0x0,
0x40,0x1,0x0,0x0,0x53,0x1,0x0,0x0,
0x80,0x1,0x0,0x0,0x93,0x1,0x0,0x0,
0xa0,0x1,0x0,0x0,0x93,0x1,0x0,0x0,
0xb0,0x1,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x40,0xf5,0x3f,
0x44,0x0,0x0,0x0,0xf,0x0,0x0,0x0,
0x9,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x1,0x0,
0xff,0xff,0xff,0xff,0x8,0x0,0x0,0x0,
0xa,0x0,0x50,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xa,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x2e,0x0,0x3c,0x1,
0x18,0x7,0x2e,0x2,0x3c,0x3,0x6c,0x7,
0x18,0x6,0x2,0x0,0x0,0x0,0x0,0x0,
0x44,0x0,0x0,0x0,0xf,0x0,0x0,0x0,
0xb,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x1,0x0,
0xff,0xff,0xff,0xff,0x8,0x0,0x0,0x0,
0xb,0x0,0x50,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xb,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x2e,0x4,0x3c,0x5,
0x18,0x7,0x2e,0x6,0x3c,0x7,0x6c,0x7,
0x18,0x6,0x2,0x0,0x0,0x0,0x0,0x0,
0x44,0x0,0x0,0x0,0xf,0x0,0x0,0x0,
0xd,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x1,0x0,
0xff,0xff,0xff,0xff,0x8,0x0,0x0,0x0,
0xc,0x0,0x50,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xc,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x2e,0x8,0x3c,0x9,
0x18,0x7,0x2e,0xa,0x3c,0xb,0x6c,0x7,
0x18,0x6,0x2,0x0,0x0,0x0,0x0,0x0,
0x44,0x0,0x0,0x0,0x7,0x0,0x0,0x0,
0x11,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x1,0x0,
0xff,0xff,0xff,0xff,0x7,0x0,0x0,0x0,
0x13,0x0,0x50,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x13,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x2e,0xc,0x3c,0xd,
0x18,0x6,0x2,0x0,0x0,0x0,0x0,0x0,
0x44,0x0,0x0,0x0,0x7,0x0,0x0,0x0,
0x13,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x1,0x0,
0xff,0xff,0xff,0xff,0x7,0x0,0x0,0x0,
0x15,0x0,0x50,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x15,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x2e,0xe,0x3c,0xf,
0x18,0x6,0x2,0x0,0x0,0x0,0x0,0x0,
0x70,0x3,0x0,0x0,0x78,0x3,0x0,0x0,
0x98,0x3,0x0,0x0,0xb0,0x3,0x0,0x0,
0xc0,0x3,0x0,0x0,0xd8,0x3,0x0,0x0,
0xe8,0x3,0x0,0x0,0xf8,0x3,0x0,0x0,
0x10,0x4,0x0,0x0,0x28,0x4,0x0,0x0,
0x60,0x4,0x0,0x0,0x78,0x4,0x0,0x0,
0xb0,0x4,0x0,0x0,0xc8,0x4,0x0,0x0,
0x0,0x5,0x0,0x0,0x18,0x5,0x0,0x0,
0x28,0x5,0x0,0x0,0x50,0x5,0x0,0x0,
0x98,0x5,0x0,0x0,0xb0,0x5,0x0,0x0,
0xe8,0x5,0x0,0x0,0x8,0x6,0x0,0x0,
0x28,0x6,0x0,0x0,0x48,0x6,0x0,0x0,
0x68,0x6,0x0,0x0,0x88,0x6,0x0,0x0,
0xa8,0x6,0x0,0x0,0xc8,0x6,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xc,0x0,0x0,0x0,0x51,0x0,0x74,0x0,
0x4d,0x0,0x75,0x0,0x6c,0x0,0x74,0x0,
0x69,0x0,0x6d,0x0,0x65,0x0,0x64,0x0,
0x69,0x0,0x61,0x0,0x0,0x0,0x0,0x0,
0x7,0x0,0x0,0x0,0x51,0x0,0x74,0x0,
0x51,0x0,0x75,0x0,0x69,0x0,0x63,0x0,
0x6b,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x5,0x0,0x0,0x0,0x56,0x0,0x69,0x0,
0x64,0x0,0x65,0x0,0x6f,0x0,0x0,0x0,
0x7,0x0,0x0,0x0,0x63,0x0,0x6f,0x0,
0x6e,0x0,0x74,0x0,0x72,0x0,0x6f,0x0,
0x6c,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x5,0x0,0x0,0x0,0x76,0x0,0x69,0x0,
0x64,0x0,0x65,0x0,0x6f,0x0,0x0,0x0,
0x3,0x0,0x0,0x0,0x75,0x0,0x72,0x0,
0x6c,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x6,0x0,0x0,0x0,0x73,0x0,0x6f,0x0,
0x75,0x0,0x72,0x0,0x63,0x0,0x65,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x9,0x0,0x0,0x0,0x69,0x0,0x73,0x0,
0x50,0x0,0x6c,0x0,0x61,0x0,0x79,0x0,
0x69,0x0,0x6e,0x0,0x67,0x0,0x0,0x0,
0x18,0x0,0x0,0x0,0x65,0x0,0x78,0x0,
0x70,0x0,0x72,0x0,0x65,0x0,0x73,0x0,
0x73,0x0,0x69,0x0,0x6f,0x0,0x6e,0x0,
0x20,0x0,0x66,0x0,0x6f,0x0,0x72,0x0,
0x20,0x0,0x69,0x0,0x73,0x0,0x50,0x0,
0x6c,0x0,0x61,0x0,0x79,0x0,0x69,0x0,
0x6e,0x0,0x67,0x0,0x0,0x0,0x0,0x0,
0x8,0x0,0x0,0x0,0x69,0x0,0x73,0x0,
0x50,0x0,0x61,0x0,0x75,0x0,0x73,0x0,
0x65,0x0,0x64,0x0,0x0,0x0,0x0,0x0,
0x17,0x0,0x0,0x0,0x65,0x0,0x78,0x0,
0x70,0x0,0x72,0x0,0x65,0x0,0x73,0x0,
0x73,0x0,0x69,0x0,0x6f,0x0,0x6e,0x0,
0x20,0x0,0x66,0x0,0x6f,0x0,0x72,0x0,
0x20,0x0,0x69,0x0,0x73,0x0,0x50,0x0,
0x61,0x0,0x75,0x0,0x73,0x0,0x65,0x0,
0x64,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x9,0x0,0x0,0x0,0x69,0x0,0x73,0x0,
0x53,0x0,0x74,0x0,0x6f,0x0,0x70,0x0,
0x70,0x0,0x65,0x0,0x64,0x0,0x0,0x0,
0x18,0x0,0x0,0x0,0x65,0x0,0x78,0x0,
0x70,0x0,0x72,0x0,0x65,0x0,0x73,0x0,
0x73,0x0,0x69,0x0,0x6f,0x0,0x6e,0x0,
0x20,0x0,0x66,0x0,0x6f,0x0,0x72,0x0,
0x20,0x0,0x69,0x0,0x73,0x0,0x53,0x0,
0x74,0x0,0x6f,0x0,0x70,0x0,0x70,0x0,
0x65,0x0,0x64,0x0,0x0,0x0,0x0,0x0,
0x8,0x0,0x0,0x0,0x61,0x0,0x75,0x0,
0x74,0x0,0x6f,0x0,0x50,0x0,0x6c,0x0,
0x61,0x0,0x79,0x0,0x0,0x0,0x0,0x0,
0x5,0x0,0x0,0x0,0x6c,0x0,0x6f,0x0,
0x6f,0x0,0x70,0x0,0x73,0x0,0x0,0x0,
0x11,0x0,0x0,0x0,0x65,0x0,0x6e,0x0,
0x64,0x0,0x4f,0x0,0x66,0x0,0x53,0x0,
0x74,0x0,0x72,0x0,0x65,0x0,0x61,0x0,
0x6d,0x0,0x50,0x0,0x6f,0x0,0x6c,0x0,
0x69,0x0,0x63,0x0,0x79,0x0,0x0,0x0,
0x20,0x0,0x0,0x0,0x65,0x0,0x78,0x0,
0x70,0x0,0x72,0x0,0x65,0x0,0x73,0x0,
0x73,0x0,0x69,0x0,0x6f,0x0,0x6e,0x0,
0x20,0x0,0x66,0x0,0x6f,0x0,0x72,0x0,
0x20,0x0,0x65,0x0,0x6e,0x0,0x64,0x0,
0x4f,0x0,0x66,0x0,0x53,0x0,0x74,0x0,
0x72,0x0,0x65,0x0,0x61,0x0,0x6d,0x0,
0x50,0x0,0x6f,0x0,0x6c,0x0,0x69,0x0,
0x63,0x0,0x79,0x0,0x0,0x0,0x0,0x0,
0x8,0x0,0x0,0x0,0x66,0x0,0x69,0x0,
0x6c,0x0,0x6c,0x0,0x4d,0x0,0x6f,0x0,
0x64,0x0,0x65,0x0,0x0,0x0,0x0,0x0,
0x17,0x0,0x0,0x0,0x65,0x0,0x78,0x0,
0x70,0x0,0x72,0x0,0x65,0x0,0x73,0x0,
0x73,0x0,0x69,0x0,0x6f,0x0,0x6e,0x0,
0x20,0x0,0x66,0x0,0x6f,0x0,0x72,0x0,
0x20,0x0,0x66,0x0,0x69,0x0,0x6c,0x0,
0x6c,0x0,0x4d,0x0,0x6f,0x0,0x64,0x0,
0x65,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xd,0x0,0x0,0x0,0x70,0x0,0x6c,0x0,
0x61,0x0,0x79,0x0,0x62,0x0,0x61,0x0,
0x63,0x0,0x6b,0x0,0x53,0x0,0x74,0x0,
0x61,0x0,0x74,0x0,0x65,0x0,0x0,0x0,
0xb,0x0,0x0,0x0,0x4d,0x0,0x65,0x0,
0x64,0x0,0x69,0x0,0x61,0x0,0x50,0x0,
0x6c,0x0,0x61,0x0,0x79,0x0,0x65,0x0,
0x72,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xc,0x0,0x0,0x0,0x50,0x0,0x6c,0x0,
0x61,0x0,0x79,0x0,0x69,0x0,0x6e,0x0,
0x67,0x0,0x53,0x0,0x74,0x0,0x61,0x0,
0x74,0x0,0x65,0x0,0x0,0x0,0x0,0x0,
0xb,0x0,0x0,0x0,0x50,0x0,0x61,0x0,
0x75,0x0,0x73,0x0,0x65,0x0,0x64,0x0,
0x53,0x0,0x74,0x0,0x61,0x0,0x74,0x0,
0x65,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xc,0x0,0x0,0x0,0x53,0x0,0x74,0x0,
0x6f,0x0,0x70,0x0,0x70,0x0,0x65,0x0,
0x64,0x0,0x53,0x0,0x74,0x0,0x61,0x0,
0x74,0x0,0x65,0x0,0x0,0x0,0x0,0x0,
0xb,0x0,0x0,0x0,0x56,0x0,0x69,0x0,
0x64,0x0,0x65,0x0,0x6f,0x0,0x4f,0x0,
0x75,0x0,0x74,0x0,0x70,0x0,0x75,0x0,
0x74,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xd,0x0,0x0,0x0,0x4b,0x0,0x65,0x0,
0x65,0x0,0x70,0x0,0x4c,0x0,0x61,0x0,
0x73,0x0,0x74,0x0,0x46,0x0,0x72,0x0,
0x61,0x0,0x6d,0x0,0x65,0x0,0x0,0x0,
0x11,0x0,0x0,0x0,0x50,0x0,0x72,0x0,
0x65,0x0,0x73,0x0,0x65,0x0,0x72,0x0,
0x76,0x0,0x65,0x0,0x41,0x0,0x73,0x0,
0x70,0x0,0x65,0x0,0x63,0x0,0x74,0x0,
0x46,0x0,0x69,0x0,0x74,0x0,0x0,0x0,
0x2,0x0,0x0,0x0,0x10,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x38,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x1,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x1,0x0,0x10,0x0,
0xff,0xff,0x0,0x0,0x1,0x0,0x0,0x0,
0x2,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x2,0x0,0x10,0x0,0xff,0xff,0x0,0x0,
0x3c,0x0,0x0,0x0,0x3,0x0,0x0,0x0,
0x4,0x0,0x0,0x0,0x0,0x0,0xff,0xff,
0xff,0xff,0xff,0xff,0x0,0x0,0x3,0x0,
0x54,0x0,0x0,0x0,0x54,0x0,0x0,0x0,
0x78,0x0,0x0,0x0,0x2,0x0,0x0,0x0,
0xa0,0x0,0x0,0x0,0xa0,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0xa0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x48,0x1,0x0,0x0,
0x4,0x0,0x10,0x0,0x6,0x0,0x50,0x0,
0x48,0x1,0x0,0x0,0x0,0x0,0x0,0x0,
0x48,0x1,0x0,0x0,0x0,0x0,0x0,0x0,
0x8,0x0,0x0,0x0,0x3,0x0,0x0,0xa0,
0xa,0x0,0x50,0x0,0xa,0x0,0x0,0x0,
0x3,0x0,0x0,0xa0,0xb,0x0,0x50,0x0,
0xc,0x0,0x0,0x0,0x3,0x0,0x0,0xa0,
0xc,0x0,0x50,0x0,0x5,0x0,0x0,0x20,
0x4,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x7,0x0,0x50,0x0,0x7,0x0,0x50,0x2,
0x6,0x0,0x0,0x0,0x4,0x0,0x0,0x0,
0x7,0x0,0x0,0x0,0x8,0x0,0x50,0x0,
0x8,0x0,0xa0,0x1,0x12,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x4,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x15,0x0,0x50,0x0,
0x15,0x0,0xf0,0x0,0x10,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x3,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x13,0x0,0x50,0x0,
0x13,0x0,0x80,0x1,0xf,0x0,0x0,0x0,
0x0,0x0,0x2,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x11,0x0,0x50,0x0,
0x11,0x0,0xc0,0x0,0xe,0x0,0x0,0x0,
0x0,0x0,0x1,0x0,0x1,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xf,0x0,0x50,0x0,
0xf,0x0,0xf0,0x0,0xc,0x0,0x0,0x0,
0x8,0x0,0x7,0x0,0x2,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xc,0x0,0xc0,0x1,
0xc,0x0,0x80,0x2,0xa,0x0,0x0,0x0,
0x8,0x0,0x7,0x0,0x1,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xb,0x0,0xc0,0x1,
0xb,0x0,0x70,0x2,0x8,0x0,0x0,0x0,
0x8,0x0,0x7,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xa,0x0,0xc0,0x1,
0xa,0x0,0x80,0x2
};
QT_WARNING_PUSH
QT_WARNING_DISABLE_MSVC(4573)
extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[] = {
{ 0, 0, [](QV4::ExecutableCompilationUnit *contextUnit, QMetaType *argTypes) {
    struct { QV4::ExecutableCompilationUnit *compilationUnit; } c { contextUnit };
    const auto *aotContext = &c;
    Q_UNUSED(aotContext);
    argTypes[0] = QMetaType::fromType<bool>();
}, 
    [](const QQmlPrivate::AOTCompiledContext *aotContext, void **argv) {
Q_UNUSED(aotContext)
Q_UNUSED(argv)
// expression for isPlaying at line 10, column 5
QObject *v2_0;
bool v2_10;
int v2_2;
int v2_8;
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(2);
#endif
while (!aotContext->loadContextIdLookup(0, &v2_0)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(2);
#endif
aotContext->initLoadContextIdLookup(0);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<bool *>(argv[0]) = bool();
}
return;
}
}
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(4);
#endif
while (!aotContext->getObjectLookup(1, v2_0, &v2_2)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(4);
#endif
aotContext->initGetObjectLookup(1, v2_0);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<bool *>(argv[0]) = bool();
}
return;
}
}
{
}
// generate_StoreReg
{
}
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(10);
#endif
while (!aotContext->getEnumLookup(3, &v2_8)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(10);
#endif
aotContext->initGetEnumLookup(3, []() { static const auto t = QMetaType::fromName("QMediaPlayer*"); return t; }().metaObject(), "PlaybackState", "PlayingState");
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<bool *>(argv[0]) = bool();
}
return;
}
}
{
}
// generate_CmpStrictEqual
v2_10 = v2_2 == v2_8;
{
}
{
}
// generate_Ret
if (argv[0]) {
    *static_cast<bool *>(argv[0]) = v2_10;
}
return;
}
 },{ 1, 0, [](QV4::ExecutableCompilationUnit *contextUnit, QMetaType *argTypes) {
    struct { QV4::ExecutableCompilationUnit *compilationUnit; } c { contextUnit };
    const auto *aotContext = &c;
    Q_UNUSED(aotContext);
    argTypes[0] = QMetaType::fromType<bool>();
}, 
    [](const QQmlPrivate::AOTCompiledContext *aotContext, void **argv) {
Q_UNUSED(aotContext)
Q_UNUSED(argv)
// expression for isPaused at line 11, column 5
QObject *v2_0;
bool v2_10;
int v2_2;
int v2_8;
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(2);
#endif
while (!aotContext->loadContextIdLookup(4, &v2_0)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(2);
#endif
aotContext->initLoadContextIdLookup(4);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<bool *>(argv[0]) = bool();
}
return;
}
}
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(4);
#endif
while (!aotContext->getObjectLookup(5, v2_0, &v2_2)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(4);
#endif
aotContext->initGetObjectLookup(5, v2_0);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<bool *>(argv[0]) = bool();
}
return;
}
}
{
}
// generate_StoreReg
{
}
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(10);
#endif
while (!aotContext->getEnumLookup(7, &v2_8)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(10);
#endif
aotContext->initGetEnumLookup(7, []() { static const auto t = QMetaType::fromName("QMediaPlayer*"); return t; }().metaObject(), "PlaybackState", "PausedState");
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<bool *>(argv[0]) = bool();
}
return;
}
}
{
}
// generate_CmpStrictEqual
v2_10 = v2_2 == v2_8;
{
}
{
}
// generate_Ret
if (argv[0]) {
    *static_cast<bool *>(argv[0]) = v2_10;
}
return;
}
 },{ 2, 0, [](QV4::ExecutableCompilationUnit *contextUnit, QMetaType *argTypes) {
    struct { QV4::ExecutableCompilationUnit *compilationUnit; } c { contextUnit };
    const auto *aotContext = &c;
    Q_UNUSED(aotContext);
    argTypes[0] = QMetaType::fromType<bool>();
}, 
    [](const QQmlPrivate::AOTCompiledContext *aotContext, void **argv) {
Q_UNUSED(aotContext)
Q_UNUSED(argv)
// expression for isStopped at line 12, column 5
QObject *v2_0;
bool v2_10;
int v2_2;
int v2_8;
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(2);
#endif
while (!aotContext->loadContextIdLookup(8, &v2_0)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(2);
#endif
aotContext->initLoadContextIdLookup(8);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<bool *>(argv[0]) = bool();
}
return;
}
}
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(4);
#endif
while (!aotContext->getObjectLookup(9, v2_0, &v2_2)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(4);
#endif
aotContext->initGetObjectLookup(9, v2_0);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<bool *>(argv[0]) = bool();
}
return;
}
}
{
}
// generate_StoreReg
{
}
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(10);
#endif
while (!aotContext->getEnumLookup(11, &v2_8)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(10);
#endif
aotContext->initGetEnumLookup(11, []() { static const auto t = QMetaType::fromName("QMediaPlayer*"); return t; }().metaObject(), "PlaybackState", "StoppedState");
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<bool *>(argv[0]) = bool();
}
return;
}
}
{
}
// generate_CmpStrictEqual
v2_10 = v2_2 == v2_8;
{
}
{
}
// generate_Ret
if (argv[0]) {
    *static_cast<bool *>(argv[0]) = v2_10;
}
return;
}
 },{ 3, 0, [](QV4::ExecutableCompilationUnit *contextUnit, QMetaType *argTypes) {
    struct { QV4::ExecutableCompilationUnit *compilationUnit; } c { contextUnit };
    const auto *aotContext = &c;
    Q_UNUSED(aotContext);
    argTypes[0] = []() { static const auto t = QMetaType::fromName("QQuickVideoOutput::EndOfStreamPolicy"); return t; }();
}, 
    [](const QQmlPrivate::AOTCompiledContext *aotContext, void **argv) {
Q_UNUSED(aotContext)
Q_UNUSED(argv)
// expression for endOfStreamPolicy at line 19, column 5
int v2_2;
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(4);
#endif
while (!aotContext->getEnumLookup(13, &v2_2)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(4);
#endif
aotContext->initGetEnumLookup(13, []() { static const auto t = QMetaType::fromName("QQuickVideoOutput*"); return t; }().metaObject(), "EndOfStreamPolicy", "KeepLastFrame");
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    const QMetaType returnType = []() { static const auto t = QMetaType::fromName("QQuickVideoOutput::EndOfStreamPolicy"); return t; }();
    returnType.destruct(argv[0]);
    returnType.construct(argv[0]);
 }
return;
}
}
{
}
{
}
// generate_Ret
if (argv[0]) {
    const QMetaType returnType = QMetaType::fromType<int>();
    returnType.destruct(argv[0]);
    returnType.construct(argv[0], &v2_2);
}
return;
}
 },{ 4, 0, [](QV4::ExecutableCompilationUnit *contextUnit, QMetaType *argTypes) {
    struct { QV4::ExecutableCompilationUnit *compilationUnit; } c { contextUnit };
    const auto *aotContext = &c;
    Q_UNUSED(aotContext);
    argTypes[0] = []() { static const auto t = QMetaType::fromName("QQuickVideoOutput::FillMode"); return t; }();
}, 
    [](const QQmlPrivate::AOTCompiledContext *aotContext, void **argv) {
Q_UNUSED(aotContext)
Q_UNUSED(argv)
// expression for fillMode at line 21, column 5
int v2_2;
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(4);
#endif
while (!aotContext->getEnumLookup(15, &v2_2)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(4);
#endif
aotContext->initGetEnumLookup(15, []() { static const auto t = QMetaType::fromName("QQuickVideoOutput*"); return t; }().metaObject(), "FillMode", "PreserveAspectFit");
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    const QMetaType returnType = []() { static const auto t = QMetaType::fromName("QQuickVideoOutput::FillMode"); return t; }();
    returnType.destruct(argv[0]);
    returnType.construct(argv[0]);
 }
return;
}
}
{
}
{
}
// generate_Ret
if (argv[0]) {
    const QMetaType returnType = QMetaType::fromType<int>();
    returnType.destruct(argv[0]);
    returnType.construct(argv[0], &v2_2);
}
return;
}
 },{ 0, 0, nullptr, nullptr }};
QT_WARNING_POP
}
}
