/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 6.9.2
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#ifdef _MSC_VER
// disable informational message "function ... selected for automatic inline expansion"
#pragma warning (disable: 4711)
#endif

static const unsigned char qt_resource_data[] = {
  // qmldir
  0x0,0x0,0x0,0x18,
  0x70,
  0x72,0x65,0x66,0x65,0x72,0x20,0x3a,0x2f,0x61,0x70,0x70,0x2f,0x6d,0x61,0x75,0x69,
  0x2f,0x63,0x6c,0x69,0x70,0x2f,0xa,
  
};

static const unsigned char qt_resource_name[] = {
  // app
  0x0,0x3,
  0x0,0x0,0x68,0x70,
  0x0,0x61,
  0x0,0x70,0x0,0x70,
    // maui
  0x0,0x4,
  0x0,0x7,0x38,0xb9,
  0x0,0x6d,
  0x0,0x61,0x0,0x75,0x0,0x69,
    // clip
  0x0,0x4,
  0x0,0x6,0xa3,0x0,
  0x0,0x63,
  0x0,0x6c,0x0,0x69,0x0,0x70,
    // views
  0x0,0x5,
  0x0,0x7c,0xfc,0xe3,
  0x0,0x76,
  0x0,0x69,0x0,0x65,0x0,0x77,0x0,0x73,
    // settings
  0x0,0x8,
  0xc,0xbb,0xb,0xc3,
  0x0,0x73,
  0x0,0x65,0x0,0x74,0x0,0x74,0x0,0x69,0x0,0x6e,0x0,0x67,0x0,0x73,
    // youtube
  0x0,0x7,
  0x0,0x6c,0xba,0x85,
  0x0,0x79,
  0x0,0x6f,0x0,0x75,0x0,0x74,0x0,0x75,0x0,0x62,0x0,0x65,
    // tags
  0x0,0x4,
  0x0,0x7,0xa7,0xe3,
  0x0,0x74,
  0x0,0x61,0x0,0x67,0x0,0x73,
    // collection
  0x0,0xa,
  0x2,0xb7,0xe4,0x3e,
  0x0,0x63,
  0x0,0x6f,0x0,0x6c,0x0,0x6c,0x0,0x65,0x0,0x63,0x0,0x74,0x0,0x69,0x0,0x6f,0x0,0x6e,
    // qmldir
  0x0,0x6,
  0x7,0x84,0x2b,0x2,
  0x0,0x71,
  0x0,0x6d,0x0,0x6c,0x0,0x64,0x0,0x69,0x0,0x72,
    // player
  0x0,0x6,
  0x7,0x72,0x8f,0xc2,
  0x0,0x70,
  0x0,0x6c,0x0,0x61,0x0,0x79,0x0,0x65,0x0,0x72,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x1,0x99,0x7d,0x57,0x24,0x58,
  // :/app
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
0x0,0x0,0x1,0x99,0x7d,0x57,0x24,0x58,
  // :/app/maui
  0x0,0x0,0x0,0xc,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x3,
0x0,0x0,0x1,0x99,0x7d,0x57,0x24,0x58,
  // :/app/maui/clip
  0x0,0x0,0x0,0x1a,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x4,
0x0,0x0,0x1,0x99,0x7d,0x57,0x24,0x58,
  // :/app/maui/clip/views
  0x0,0x0,0x0,0x28,0x0,0x2,0x0,0x0,0x0,0x6,0x0,0x0,0x0,0x5,
0x0,0x0,0x1,0x99,0x7d,0x57,0x24,0x58,
  // :/app/maui/clip/views/tags
  0x0,0x0,0x0,0x62,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0xf,
0x0,0x0,0x1,0x99,0x7d,0x57,0x24,0x58,
  // :/app/maui/clip/views/youtube
  0x0,0x0,0x0,0x4e,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0xe,
0x0,0x0,0x1,0x99,0x7d,0x57,0x24,0x58,
  // :/app/maui/clip/views/collection
  0x0,0x0,0x0,0x70,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0xd,
0x0,0x0,0x1,0x99,0x7d,0x57,0x24,0x58,
  // :/app/maui/clip/views/player
  0x0,0x0,0x0,0x9c,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0xc,
0x0,0x0,0x1,0x99,0x7d,0x57,0x24,0x58,
  // :/app/maui/clip/views/qmldir
  0x0,0x0,0x0,0x8a,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x99,0x7d,0x57,0x24,0x58,
  // :/app/maui/clip/views/settings
  0x0,0x0,0x0,0x38,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0xb,
0x0,0x0,0x1,0x99,0x7d,0x57,0x24,0x58,
  // :/app/maui/clip/views/settings/qmldir
  0x0,0x0,0x0,0x8a,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x99,0x7d,0x57,0x24,0x58,
  // :/app/maui/clip/views/player/qmldir
  0x0,0x0,0x0,0x8a,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x99,0x7d,0x57,0x24,0x58,
  // :/app/maui/clip/views/collection/qmldir
  0x0,0x0,0x0,0x8a,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x99,0x7d,0x57,0x24,0x58,
  // :/app/maui/clip/views/youtube/qmldir
  0x0,0x0,0x0,0x8a,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x99,0x7d,0x57,0x24,0x58,
  // :/app/maui/clip/views/tags/qmldir
  0x0,0x0,0x0,0x8a,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x99,0x7d,0x57,0x24,0x58,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#if defined(QT_INLINE_NAMESPACE)
inline namespace QT_NAMESPACE {
#elif defined(QT_NAMESPACE)
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);
bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_clip_raw_qml_0_extra_qmldirs)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_clip_raw_qml_0_extra_qmldirs)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_clip_raw_qml_0_extra_qmldirs)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_clip_raw_qml_0_extra_qmldirs)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

#ifdef __clang__
#   pragma clang diagnostic push
#   pragma clang diagnostic ignored "-Wexit-time-destructors"
#endif

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_clip_raw_qml_0_extra_qmldirs)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_clip_raw_qml_0_extra_qmldirs)(); }
   } dummy;
}

#ifdef __clang__
#   pragma clang diagnostic pop
#endif
