/****************************************************************************
** Meta object code from reading C++ file 'videosmodel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.9.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../maui-clip-4.0.2/src/models/videosmodel.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'videosmodel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.9.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN11VideosModelE_t {};
} // unnamed namespace

template <> constexpr inline auto VideosModel::qt_create_metaobjectdata<qt_meta_tag_ZN11VideosModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "VideosModel",
        "urlsChanged",
        "",
        "foldersChanged",
        "autoReloadChanged",
        "autoScanChanged",
        "recursiveChanged",
        "recursive",
        "limitChanged",
        "limit",
        "filesChanged",
        "remove",
        "index",
        "deleteAt",
        "append",
        "QVariantMap",
        "item",
        "appendUrl",
        "url",
        "clear",
        "rescan",
        "setRecursive",
        "setlimit",
        "urls",
        "folders",
        "QList<QUrl>",
        "autoScan",
        "autoReload",
        "files"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'urlsChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'foldersChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'autoReloadChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'autoScanChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'recursiveChanged'
        QtMocHelpers::SignalData<void(bool)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 7 },
        }}),
        // Signal 'limitChanged'
        QtMocHelpers::SignalData<void(int)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 9 },
        }}),
        // Signal 'filesChanged'
        QtMocHelpers::SignalData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'remove'
        QtMocHelpers::SlotData<bool(const int &)>(11, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Int, 12 },
        }}),
        // Slot 'deleteAt'
        QtMocHelpers::SlotData<bool(const int &)>(13, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Int, 12 },
        }}),
        // Slot 'append'
        QtMocHelpers::SlotData<void(const QVariantMap &)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 15, 16 },
        }}),
        // Slot 'appendUrl'
        QtMocHelpers::SlotData<void(const QString &)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 18 },
        }}),
        // Slot 'clear'
        QtMocHelpers::SlotData<void()>(19, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'rescan'
        QtMocHelpers::SlotData<void()>(20, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setRecursive'
        QtMocHelpers::SlotData<void(bool)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 7 },
        }}),
        // Slot 'setlimit'
        QtMocHelpers::SlotData<void(int)>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 9 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'urls'
        QtMocHelpers::PropertyData<QStringList>(23, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable | QMC::Resettable | QMC::StdCppSet, 0),
        // property 'folders'
        QtMocHelpers::PropertyData<QList<QUrl>>(24, 0x80000000 | 25, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Final, 1),
        // property 'recursive'
        QtMocHelpers::PropertyData<bool>(7, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'autoScan'
        QtMocHelpers::PropertyData<bool>(26, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'autoReload'
        QtMocHelpers::PropertyData<bool>(27, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'limit'
        QtMocHelpers::PropertyData<int>(9, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable, 5),
        // property 'files'
        QtMocHelpers::PropertyData<QStringList>(28, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Final, 6),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<VideosModel, qt_meta_tag_ZN11VideosModelE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject VideosModel::staticMetaObject = { {
    QMetaObject::SuperData::link<MauiList::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11VideosModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11VideosModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN11VideosModelE_t>.metaTypes,
    nullptr
} };

void VideosModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<VideosModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->urlsChanged(); break;
        case 1: _t->foldersChanged(); break;
        case 2: _t->autoReloadChanged(); break;
        case 3: _t->autoScanChanged(); break;
        case 4: _t->recursiveChanged((*reinterpret_cast< std::add_pointer_t<bool>>(_a[1]))); break;
        case 5: _t->limitChanged((*reinterpret_cast< std::add_pointer_t<int>>(_a[1]))); break;
        case 6: _t->filesChanged(); break;
        case 7: { bool _r = _t->remove((*reinterpret_cast< std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 8: { bool _r = _t->deleteAt((*reinterpret_cast< std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 9: _t->append((*reinterpret_cast< std::add_pointer_t<QVariantMap>>(_a[1]))); break;
        case 10: _t->appendUrl((*reinterpret_cast< std::add_pointer_t<QString>>(_a[1]))); break;
        case 11: _t->clear(); break;
        case 12: _t->rescan(); break;
        case 13: _t->setRecursive((*reinterpret_cast< std::add_pointer_t<bool>>(_a[1]))); break;
        case 14: _t->setlimit((*reinterpret_cast< std::add_pointer_t<int>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (VideosModel::*)()>(_a, &VideosModel::urlsChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (VideosModel::*)()>(_a, &VideosModel::foldersChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (VideosModel::*)()>(_a, &VideosModel::autoReloadChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (VideosModel::*)()>(_a, &VideosModel::autoScanChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (VideosModel::*)(bool )>(_a, &VideosModel::recursiveChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (VideosModel::*)(int )>(_a, &VideosModel::limitChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (VideosModel::*)()>(_a, &VideosModel::filesChanged, 6))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 1:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QList<QUrl> >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QStringList*>(_v) = _t->urls(); break;
        case 1: *reinterpret_cast<QList<QUrl>*>(_v) = _t->folders(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->recursive(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->autoScan(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->autoReload(); break;
        case 5: *reinterpret_cast<int*>(_v) = _t->limit(); break;
        case 6: *reinterpret_cast<QStringList*>(_v) = _t->files(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setUrls(*reinterpret_cast<QStringList*>(_v)); break;
        case 2: _t->setRecursive(*reinterpret_cast<bool*>(_v)); break;
        case 3: _t->setAutoScan(*reinterpret_cast<bool*>(_v)); break;
        case 4: _t->setAutoReload(*reinterpret_cast<bool*>(_v)); break;
        case 5: _t->setlimit(*reinterpret_cast<int*>(_v)); break;
        default: break;
        }
    }
if (_c == QMetaObject::ResetProperty) {
        switch (_id) {
        case 0: _t->resetUrls(); break;
        default: break;
        }
    }
}

const QMetaObject *VideosModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *VideosModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11VideosModelE_t>.strings))
        return static_cast<void*>(this);
    return MauiList::qt_metacast(_clname);
}

int VideosModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = MauiList::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 15)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 15;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 15)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 15;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    return _id;
}

// SIGNAL 0
void VideosModel::urlsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void VideosModel::foldersChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void VideosModel::autoReloadChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void VideosModel::autoScanChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void VideosModel::recursiveChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void VideosModel::limitChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void VideosModel::filesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}
QT_WARNING_POP
