/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.freedesktop.ScreenSaver.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * This file may have been hand-edited. Look for HAND-EDIT comments
 * before re-generating it.
 */

#include "screensaverdbusinterface.h"

/*
 * Implementation of interface class OrgFreedesktopDBusIntrospectableInterface
 */

OrgFreedesktopDBusIntrospectableInterface::OrgFreedesktopDBusIntrospectableInterface(const QString &service, const QString &path, const QDBusConnection &connection, QObject *parent)
    : QDBusAbstractInterface(service, path, staticInterfaceName(), connection, parent)
{
}

OrgFreedesktopDBusIntrospectableInterface::~OrgFreedesktopDBusIntrospectableInterface()
{
}

/*
 * Implementation of interface class OrgFreedesktopDBusPeerInterface
 */

OrgFreedesktopDBusPeerInterface::OrgFreedesktopDBusPeerInterface(const QString &service, const QString &path, const QDBusConnection &connection, QObject *parent)
    : QDBusAbstractInterface(service, path, staticInterfaceName(), connection, parent)
{
}

OrgFreedesktopDBusPeerInterface::~OrgFreedesktopDBusPeerInterface()
{
}

/*
 * Implementation of interface class OrgFreedesktopDBusPropertiesInterface
 */

OrgFreedesktopDBusPropertiesInterface::OrgFreedesktopDBusPropertiesInterface(const QString &service, const QString &path, const QDBusConnection &connection, QObject *parent)
    : QDBusAbstractInterface(service, path, staticInterfaceName(), connection, parent)
{
}

OrgFreedesktopDBusPropertiesInterface::~OrgFreedesktopDBusPropertiesInterface()
{
}

/*
 * Implementation of interface class OrgFreedesktopScreenSaverInterface
 */

OrgFreedesktopScreenSaverInterface::OrgFreedesktopScreenSaverInterface(const QString &service, const QString &path, const QDBusConnection &connection, QObject *parent)
    : QDBusAbstractInterface(service, path, staticInterfaceName(), connection, parent)
{
}

OrgFreedesktopScreenSaverInterface::~OrgFreedesktopScreenSaverInterface()
{
}

/*
 * Implementation of interface class OrgKdeScreensaverInterface
 */

OrgKdeScreensaverInterface::OrgKdeScreensaverInterface(const QString &service, const QString &path, const QDBusConnection &connection, QObject *parent)
    : QDBusAbstractInterface(service, path, staticInterfaceName(), connection, parent)
{
}

OrgKdeScreensaverInterface::~OrgKdeScreensaverInterface()
{
}


#include "moc_screensaverdbusinterface.cpp"
